@@ -21,7 +21,7 @@ def __init_logging():
 
 
 def __init_config():
-    config_file = os.path.join(FINTIX_HOME_DIR, "application.properties")
+    config_file = os.path.join(FINTIX_HOME_DIR, "config", "application.properties")
     Config.getInstance().init(config_file)
 
 
