@@ -32,6 +32,7 @@ class DataCallbackHandler:
              model=None,
              model_name=None,
              phase=None,
+             data_source=None,
              input_topic=None,
              trigger_type=None,
              trigger_interval=None,
@@ -43,9 +44,9 @@ class DataCallbackHandler:
         self.model_name = model_name
         self.config = Config.getInstance()
         self.kafka_settings = {
-            'bootstrap.servers': '192.168.2.102:9092',
+            'bootstrap.servers': f'{data_source}',
             'group.id': f'{model_name}-model-handler',
-            'client.id': f'{model_name}-model-handler_1',
+            'client.id': f'{model_name}-model-handler_client',
             'enable.auto.commit': True,
             'session.timeout.ms': 6000,
             'default.topic.config': {
